pub struct LanguageConfig { /* private fields */ }Implementations
Sourceimpl LanguageConfig
impl LanguageConfig
pub fn language(&self) -> &Language
pub fn classify(&self, kind: &str) -> NodeRole
Sourcepub fn is_test_context(
&self,
parser: &mut dyn AstParser,
path: &Path,
content: &str,
start_line: usize,
end_line: usize,
) -> bool
pub fn is_test_context( &self, parser: &mut dyn AstParser, path: &Path, content: &str, start_line: usize, end_line: usize, ) -> bool
Returns true if the given line range is inside test code.
Detection is language-specific: some languages need to parse the source, others rely on file path conventions alone.